@@ -183,7 +183,9 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
     if (uri.isLocalFile ()) {
         for (Node *p = node->parentNode (); p; p = p->parentNode ()) {
             Mrl *m = p->mrl ();
-            if (m && !m->src.isEmpty () && !URL (m->src).isLocalFile ()) {
+            if (m && !m->src.isEmpty () &&
+                    m->src != "Playlist://" &&
+                    !URL (m->src).isLocalFile ()) {
                 errorLog () << "local acces denied\n";
                 ready ();
                 return true;
