@@ -24,6 +24,7 @@
 #include <string.h>
 #include <time.h>
 #include "expression.h"
+#include "triestring.h"
 
 using namespace KMPlayer;
 
@@ -65,7 +66,7 @@ struct AST : public Expression {
     virtual int toInt () const;
     virtual float toFloat () const;
     virtual String toString () const;
-    virtual NodeValueList *toNodeList () const;
+    virtual NodeValueList *toNodeList () const; // uncachable
     virtual Type type () const;
     virtual void setRoot (Node *root);
     void setRoot (Node *root, Attribute *a);
@@ -161,6 +162,7 @@ struct Step : public StringBase {
     }
 #endif
 
+    TrieString attr;
     bool any_node;
     bool is_attr;
 };
@@ -198,6 +200,12 @@ struct StringLiteral : public StringBase {
 #endif
 };
 
+struct Not : public BoolBase {
+    Not (EvalState *ev) : BoolBase (ev) {}
+
+    virtual bool toBool () const;
+};
+
 struct HoursFromTime : public IntegerBase {
     HoursFromTime (EvalState *ev) : IntegerBase (ev) {}
 
@@ -240,6 +248,12 @@ struct Concat : public StringBase {
     virtual String toString () const;
 };
 
+struct StringJoin : public StringBase {
+    StringJoin (EvalState *ev) : StringBase (ev) {}
+
+    virtual String toString () const;
+};
+
 struct CurrentTime : public StringBase {
     CurrentTime (EvalState *ev) : StringBase (ev) {}
 
@@ -323,6 +337,17 @@ struct Minus : public NumberBase {
 #endif
 };
 
+struct Join : public AST {
+    Join (EvalState *ev, AST *children) : AST (ev) {
+        first_child = children;
+    }
+
+    virtual NodeValueList *toNodeList () const;
+#ifdef KMPLAYER_EXPR_DEBUG
+    virtual void dump () const;
+#endif
+};
+
 struct Comparison : public BoolBase {
     enum CompType {
         lt = 1, lteq, eq, noteq, gt, gteq, land, lor
@@ -508,7 +533,9 @@ bool Step::matches (Node *n) {
 }
 
 bool Step::matches (Attribute *a) {
-    return any_node || string == a->name ().toString ();
+    if (attr.isNull () && !string.isEmpty ())
+        attr = (const char *) string;
+    return any_node || attr == a->name ();
 }
 
 bool Step::selected (Node *n, Attribute *a) {
@@ -635,6 +662,14 @@ AST::Type StringLiteral::type () const {
     return TString;
 }
 
+bool Not::toBool () const {
+    if (eval_state->sequence != sequence) {
+        sequence = eval_state->sequence;
+        b = first_child ? !first_child->toBool () : true;
+    }
+    return b;
+}
+
 int HoursFromTime::toInt () const {
     if (eval_state->sequence != sequence) {
         if (first_child) {
@@ -733,6 +768,28 @@ String Concat::toString () const {
     return string;
 }
 
+String StringJoin::toString () const {
+    if (eval_state->sequence != sequence) {
+        sequence = eval_state->sequence;
+        string.clear ();
+        AST *child = first_child;
+        if (child) {
+            NodeValueList *lst = child->toNodeList ();
+            NodeValueItem *n = lst->first();
+            if (n) {
+                String sep;
+                if (child->next_sibling)
+                    sep = child->next_sibling->toString ();
+                string = n->data.value ();
+                for (n = n->nextSibling (); n; n = n->nextSibling ())
+                    string += sep + n->data.value ();
+            }
+            delete lst;
+        }
+    }
+    return string;
+}
+
 String CurrentTime::toString () const {
     if (eval_state->sequence != sequence) {
         char buf[200];
@@ -780,19 +837,11 @@ static void sortList (NodeValueList *lst, Expression *expr) {
     }
     if (lt.first ()) {
         sortList (&lt, expr);
-        for (NodeValueItem *itm = lt.first (); itm; itm = lt.first ()) {
-            NodeValueItemPtr s = itm;
-            lt.remove (itm);
-            lst->insertBefore (itm, cur);
-        }
+        lst->splice (lst->first (), lt);
     }
     if (gt.first ()) {
         sortList (&gt, expr);
-        for (NodeValueItem *itm = gt.first (); itm; itm = gt.first ()) {
-            NodeValueItemPtr s = itm;
-            gt.remove (itm);
-            lst->append (itm);
-        }
+        lst->splice (NULL, gt);
     }
 }
 
@@ -953,6 +1002,27 @@ void Minus::dump () const {
 }
 #endif
 
+NodeValueList *Join::toNodeList () const {
+    if (first_child) {
+        NodeValueList *lst = first_child->toNodeList ();
+        if (first_child->next_sibling) {
+            NodeValueList *l2 = first_child->next_sibling->toNodeList ();
+            lst->splice (NULL, *l2);
+            delete l2;
+        }
+        return lst;
+    }
+    return AST::toNodeList ();
+}
+
+#ifdef KMPLAYER_EXPR_DEBUG
+void Join::dump () const {
+    fprintf (stderr, "| [");
+    AST::dump();
+    fprintf (stderr, " ]");
+}
+#endif
+
 bool Comparison::toBool () const {
     AST::Type t1 = first_child->type ();
     AST::Type t2 = first_child->next_sibling->type ();
@@ -1241,12 +1311,16 @@ static bool parseFunction (const char *str, const char **end, AST *ast) {
                     func = new CurrentDate (ast->eval_state);
                 else if (name == "last")
                     func = new Last (ast->eval_state);
+                else if (name == "not")
+                    func = new Not (ast->eval_state);
                 else if (name == "number")
                     func = new Number (ast->eval_state);
                 else if (name == "position")
                     func = new Position (ast->eval_state);
                 else if (name == "sort")
                     func = new Sort (ast->eval_state);
+                else if (name == "string-join")
+                    func = new StringJoin (ast->eval_state);
                 else
                     return false;
                 appendASTChild (ast, func);
@@ -1347,7 +1421,7 @@ static bool parseExpression (const char *str, const char **end, AST *ast) {
         while (true) {
             str = parseSpace (str, end) ? *end : str;
             op = *str;
-            if (op == '+' || op == '-') {
+            if (op == '+' || op == '-' || op == '|') {
                 AST tmp (ast->eval_state);
                 if (parseTerm (str + 1, end, &tmp)) {
                     AST *chlds = releaseLastASTChild (ast);
@@ -1355,7 +1429,9 @@ static bool parseExpression (const char *str, const char **end, AST *ast) {
                     tmp.first_child = NULL;
                     appendASTChild (ast, op == '+'
                             ? (AST *) new Plus (ast->eval_state, chlds)
-                            : (AST *) new Minus (ast->eval_state, chlds));
+                            :  op == '-'
+                                ? (AST *) new Minus (ast->eval_state, chlds)
+                                : (AST *) new Join (ast->eval_state, chlds));
                     str = *end;
                 }
             } else {
