@@ -116,8 +116,7 @@ KMPLAYER_NO_EXPORT void ASX::Entry::activate () {
                 document ()->message (MsgInfoString, &inf);
             }
         } else if (e->id == id_node_duration) {
-            String s = static_cast <Element *> (e)->getAttribute (
-                    StringPool::attr_value);
+            String s = static_cast<Element*>(e)->getAttribute (Ids::attr_value);
             int pos = parseTimeString( s );
             if (pos > 0)
                 duration_timer = document()->post (
