@@ -116,9 +116,9 @@ void ATOM::Link::closed () {
     String href;
     String rel;
     for (Attribute *a = attributes ().first (); a; a = a->nextSibling ()) {
-        if (a->name () == StringPool::attr_href)
+        if (a->name () == Ids::attr_href)
             href = a->value ();
-        else if (a->name () == StringPool::attr_title)
+        else if (a->name () == Ids::attr_title)
             title = a->value ();
         else if (a->name () == "rel")
             rel = a->value ();
@@ -132,9 +132,9 @@ void ATOM::Link::closed () {
 
 void ATOM::Content::closed () {
     for (Attribute *a = attributes ().first (); a; a = a->nextSibling ()) {
-        if (a->name () == StringPool::attr_src)
+        if (a->name () == Ids::attr_src)
             src = a->value ();
-        else if (a->name () == StringPool::attr_type) {
+        else if (a->name () == Ids::attr_type) {
             String v = a->value ().lower ();
             if (v == "text")
                 mimetype = "text/plain";
@@ -229,18 +229,18 @@ void ATOM::MediaGroup::addSummary (Node *p, Node *rating_node) {
             desc = c->innerText ();
             break;
         case id_node_media_player:
-            player = static_cast <Element *> (c)->getAttribute (StringPool::attr_url);
+            player = static_cast <Element *> (c)->getAttribute (Ids::attr_url);
             break;
         case id_node_media_thumbnail:
         {
             Element *e = static_cast <Element *> (c);
-            String url = e->getAttribute (StringPool::attr_url);
+            String url = e->getAttribute (Ids::attr_url);
             if (!url.isEmpty ()) {
                 images += String ("<img region=\"image\" src=\"") + url + Char ('"');
-                String w = e->getAttribute (StringPool::attr_width);
+                String w = e->getAttribute (Ids::attr_width);
                 if (!w.isEmpty ())
                     images += String (" width=\"") + w + Char ('"');
-                String h = e->getAttribute (StringPool::attr_height);
+                String h = e->getAttribute (Ids::attr_height);
                 if (!h.isEmpty ())
                     images += String (" height=\"") + h + Char ('"');
                 images += String (" dur=\"20\" transIn=\"fade\" fill=\"transition\" fit=\"meet\"/>");
@@ -297,15 +297,15 @@ void ATOM::MediaContent::closed () {
     int fsize = 0;
     TrieString fs ("fileSize");
     for (Attribute *a = attributes ().first (); a; a = a->nextSibling ()) {
-        if (a->name () == StringPool::attr_url)
+        if (a->name () == Ids::attr_url)
             src = a->value();
-        else if (a->name () == StringPool::attr_type)
+        else if (a->name () == Ids::attr_type)
             mimetype = a->value ();
-        else if (a->name () == StringPool::attr_height)
+        else if (a->name () == Ids::attr_height)
             size.height = a->value ().toInt ();
-        else if (a->name () == StringPool::attr_width)
+        else if (a->name () == Ids::attr_width)
             size.width = a->value ().toInt ();
-        else if (a->name () == StringPool::attr_width)
+        else if (a->name () == Ids::attr_width)
             size.width = a->value ().toInt ();
         else if (a->name () == fs)
             fsize = a->value ().toInt ();
