@@ -105,7 +105,7 @@ KDE_NO_EXPORT KMPlayer::Node *Recents::childFromTag (const String & tag) {
 }
 
 KDE_NO_EXPORT void Recents::message (KMPlayer::MessageType msg, void *data) {
-    if (KMPlayer::MsgChildFinished)
+    if (KMPlayer::MsgChildFinished == msg)
         finish ();
     else
         FileDocument::message (msg, data);
@@ -115,14 +115,14 @@ KDE_NO_CDTOR_EXPORT
 Recent::Recent (KMPlayer::NodePtr & doc, Application * a, const String &url)
   : KMPlayer::Mrl (doc, id_node_recent_node), app (a) {
     src = url;
-    setAttribute (KMPlayer::StringPool::attr_url, url);
+    setAttribute (KMPlayer::Ids::attr_url, url);
 }
 
 KDE_NO_EXPORT void Recent::closed () {
     if (src.isEmpty ())
-        src = getAttribute (KMPlayer::StringPool::attr_url);
+        src = getAttribute (KMPlayer::Ids::attr_url);
     if (title.isEmpty ())
-        title = getAttribute (KMPlayer::StringPool::attr_title);
+        title = getAttribute (KMPlayer::Ids::attr_title);
     KMPlayer::Mrl::closed ();
 }
 
@@ -140,7 +140,7 @@ Group::Group (KMPlayer::NodePtr & doc, Application * a, const String & pn)
   : Element (doc, KMPlayer::id_node_group_node), app (a) {
     title = pn;
     if (!pn.isEmpty ())
-        setAttribute (KMPlayer::StringPool::attr_title, pn);
+        setAttribute (KMPlayer::Ids::attr_title, pn);
 }
 
 KDE_NO_EXPORT KMPlayer::Node *Group::childFromTag (const String & tag) {
@@ -155,7 +155,7 @@ KDE_NO_EXPORT KMPlayer::Node *Group::childFromTag (const String & tag) {
 
 KDE_NO_EXPORT void Group::closed () {
     if (title.isEmpty ())
-        title = getAttribute (KMPlayer::StringPool::attr_title);
+        title = getAttribute (KMPlayer::Ids::attr_title);
     Element::closed ();
 }
 
@@ -186,6 +186,7 @@ void Playlist::show (View *view)
     if (!open)
         deleteAuxiliaries (this);
     if (view->show) {
+        TrieString aspect_ratio ("aspectRatio");
         Node *before = NULL;
         if (!view->before)
             view->before = evaluateExpr (view->getAttribute ("before"));
@@ -212,10 +213,16 @@ void Playlist::show (View *view)
 
                 PlaylistItem *pli = new PlaylistItem (m_doc, app, false);
                 NodePtr guard = pli;
-                pli->setAttribute (StringPool::attr_url,
-                        e->getAttribute (StringPool::attr_url));
-                pli->setAttribute (StringPool::attr_title,
-                        e->getAttribute (StringPool::attr_title));
+                AttributeList attrs;
+                for (Attribute *a = e->attributes ().first ();
+                        a; a = a->nextSibling ())
+                    if (a->name () == Ids::attr_url ||
+                            a->name () == Ids::attr_title ||
+                            a->name () == Ids::attr_panzoom ||
+                            a->name () == aspect_ratio)
+                        attrs.append (new Attribute (TrieString (),
+                                    a->name (), a->value ()));
+                pli->setAttributes (attrs);
                 pli->setAuxiliaryNode (true);
                 pli->closed ();
 
@@ -229,7 +236,7 @@ void Playlist::show (View *view)
                     PlaylistGroup *group;
                     if (it == groups->end ()) {
                         PlaylistGroup *g = new PlaylistGroup(m_doc, app, false);
-                        g->setAttribute (StringPool::attr_title, groupBy);
+                        g->setAttribute (Ids::attr_title, groupBy);
                         g->setAuxiliaryNode (true);
                         g->closed ();
                         group = g;
@@ -305,7 +312,7 @@ KDE_NO_EXPORT KMPlayer::Node *Playlist::childFromTag (const String & tag) {
 }
 
 KDE_NO_EXPORT void Playlist::message (KMPlayer::MessageType msg, void *data) {
-    if (KMPlayer::MsgChildFinished && !playmode)
+    if (KMPlayer::MsgChildFinished == msg && !playmode)
         finish ();
     else
         FileDocument::message (msg, data);
@@ -313,7 +320,7 @@ KDE_NO_EXPORT void Playlist::message (KMPlayer::MessageType msg, void *data) {
 
 KDE_NO_CDTOR_EXPORT
 PlaylistItemBase::PlaylistItemBase (KMPlayer::NodePtr &d, short i, Application *a, bool pm)
-  : KMPlayer::Mrl (d, i), app (a), playmode (pm) {
+  : KMPlayer::Mrl (d, i), app (a), playmode (pm), hidden (false) {
 }
 
 KDE_NO_EXPORT void PlaylistItemBase::activate () {
@@ -352,20 +359,30 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
 
 KDE_NO_EXPORT void PlaylistItemBase::closed () {
     if (title.isEmpty ())
-        title = getAttribute (KMPlayer::StringPool::attr_title);
+        title = getAttribute (KMPlayer::Ids::attr_title);
     KMPlayer::Mrl::closed ();
 }
 
+void *PlaylistItemBase::role (KMPlayer::RoleType msg, void *content)
+{
+    if (hidden) {
+        if (KMPlayer::RolePlaylist == msg)
+            return NULL;
+        else if (KMPlayer::RoleCaption == msg)
+            return (KMPlayer::PlaylistRole *) this;
+    }
+    return Mrl::role (msg, content);
+}
 KDE_NO_CDTOR_EXPORT
 PlaylistItem::PlaylistItem (KMPlayer::NodePtr & doc, Application * a, bool pm, const String &url)
   : PlaylistItemBase (doc, KMPlayer::id_node_playlist_item, a, pm) {
     src = url;
-    setAttribute (KMPlayer::StringPool::attr_url, url);
+    setAttribute (KMPlayer::Ids::attr_url, url);
 }
 
 KDE_NO_EXPORT void PlaylistItem::closed () {
     if (src.isEmpty ())
-        src = getAttribute (KMPlayer::StringPool::attr_url);
+        src = getAttribute (KMPlayer::Ids::attr_url);
     PlaylistItemBase::closed ();
 }
 
@@ -395,7 +412,7 @@ KMPlayer::Node *PlaylistGroupBase::childFromTag (const String & tag) {
 
 KDE_NO_EXPORT void PlaylistGroupBase::closed () {
     if (title.isEmpty ())
-        title = getAttribute (KMPlayer::StringPool::attr_title);
+        title = getAttribute (KMPlayer::Ids::attr_title);
     Element::closed ();
 }
 
@@ -412,7 +429,7 @@ const char *PlaylistGroup::nodeName () const
 }
 
 PlaylistMetaGroup::PlaylistMetaGroup (NodePtr &doc, Application *a)
- : PlaylistGroupBase (doc, KMPlayer::id_node_meta_group, a, false)
+ : Mrl (doc, KMPlayer::id_node_meta_group), app (a)
 {}
 
 void PlaylistMetaGroup::closed ()
@@ -425,14 +442,25 @@ void PlaylistMetaGroup::closed ()
                 static_cast <Playlist *> (p)->meta = this;
             break;
         }
-    PlaylistGroupBase::closed ();
+    title = getAttribute (KMPlayer::Ids::attr_title);
+    Mrl::closed ();
+}
+
+void PlaylistMetaGroup::activate ()
+{
+    document ()->message (MsgShowMeta, (Node *) this);
 }
 
 Node *PlaylistMetaGroup::childFromTag (const String &tag)
 {
-    if (tag == "views")
+    if (tag == "views") {
         return new Views (m_doc);
-    return PlaylistGroupBase::childFromTag (tag);
+    } else if (tag == "item") {
+        PlaylistItem *item = new PlaylistItem (m_doc, app, false);
+        item->hidden = true;
+        return item;
+    }
+    return NULL;
 }
 
 Views::Views (KMPlayer::NodePtr &doc) : Element (doc, id_node_meta_views)
@@ -440,10 +468,17 @@ Views::Views (KMPlayer::NodePtr &doc) : Element (doc, id_node_meta_views)
 
 void Views::closed ()
 {
+    int view = 0;
+    PlaylistRole *title = (PlaylistRole *) document ()->role (RolePlaylist);
+    if (title)
+        view = Config ().readNumEntry (
+                String (GCONF_KEY_LISTS_VIEW) + Char ('/') + title->caption (),
+                0);
     for (Node *c = firstChild (); c; c = c->nextSibling ())
         if (id_node_meta_view == c->id) {
             active_view = c;
-            break;
+            if (--view < 0)
+                break;
         }
     Element::closed ();
 }
@@ -483,7 +518,7 @@ View::~View ()
 
 void View::closed ()
 {
-    title = getAttribute (KMPlayer::StringPool::attr_title);
+    title = getAttribute (KMPlayer::Ids::attr_title);
     groupBy = getAttribute ("groupBy");
     if (title.isEmpty ()) {
         title = groupBy;
@@ -498,9 +533,29 @@ void View::activate ()
     debugLog () << "View::activate " << m_doc->id << endl;
     if (m_doc->id == id_node_playlist_document)
         static_cast <Playlist *> (m_doc.ptr ())->show (this);
+
+    PlaylistRole *title = (PlaylistRole *) document ()->role (RolePlaylist);
+    if (title) {
+        int sibling = 0;
+        for (Node *c = previousSibling(); c; c = c->previousSibling ())
+            if (id_node_meta_view == c->id)
+                sibling++;
+        Config ().writeEntry (
+                String (GCONF_KEY_LISTS_VIEW) + Char ('/') + title->caption (),
+                sibling);
+    }
     finish ();
 }
 
+void *View::role (KMPlayer::RoleType msg, void *content)
+{
+    if (KMPlayer::RolePlaylist == msg)
+        return NULL;
+    else if (KMPlayer::RoleCaption == msg)
+        return (KMPlayer::PlaylistRole *) this;
+    return Element::role (msg, content);
+}
+
 KDE_NO_CDTOR_EXPORT
 HtmlObject::HtmlObject (KMPlayer::NodePtr &doc, Application *a, bool pm)
   : PlaylistItemBase (doc, KMPlayer::id_node_html_object, a, pm) {}
@@ -516,17 +571,17 @@ KDE_NO_EXPORT void HtmlObject::closed () {
     for (Node *n = firstChild (); n; n = n->nextSibling ()) {
         if (n->id == KMPlayer::id_node_param) {
             KMPlayer::Element *e = static_cast <KMPlayer::Element *> (n);
-            String name = e->getAttribute (KMPlayer::StringPool::attr_name);
+            String name = e->getAttribute (KMPlayer::Ids::attr_name);
             if (name == "type")
-                mimetype = e->getAttribute (KMPlayer::StringPool::attr_value);
+                mimetype = e->getAttribute (KMPlayer::Ids::attr_value);
             else if (name == "movie")
-                src = e->getAttribute (KMPlayer::StringPool::attr_value);
+                src = e->getAttribute (KMPlayer::Ids::attr_value);
         } else if (n->id == KMPlayer::id_node_html_embed) {
             KMPlayer::Element *e = static_cast <KMPlayer::Element *> (n);
-            String type = e->getAttribute (KMPlayer::StringPool::attr_type);
+            String type = e->getAttribute (KMPlayer::Ids::attr_type);
             if (!type.isEmpty ())
                 mimetype = type;
-            String asrc = e->getAttribute (KMPlayer::StringPool::attr_src);
+            String asrc = e->getAttribute (KMPlayer::Ids::attr_src);
             if (!asrc.isEmpty ())
                 src = asrc;
         }
@@ -553,7 +608,7 @@ Node *Generator::childFromTag (const String &tag) {
 String Generator::genReadAsk (Control *ctr, Node *n) {
     String title;
     String desc;
-    String type = static_cast<Element*>(n)->getAttribute(StringPool::attr_type);
+    String type = static_cast<Element*>(n)->getAttribute(Ids::attr_type);
     String key = static_cast<Element*>(n)->getAttribute ("key");
     String def = static_cast<Element*>(n)->getAttribute ("default");
     String input;
@@ -691,7 +746,7 @@ void Generator::activate () {
     canceled = false;
     Node *n = firstChild ();
     if (n && n->id == id_node_gen_generator) {
-        title = static_cast<Element *>(n)->getAttribute (StringPool::attr_name);
+        title = static_cast<Element *>(n)->getAttribute (Ids::attr_name);
         for (Node *c = n->firstChild (); c && !canceled; c = c->nextSibling ())
             switch (c->id) {
             case id_node_gen_input:
