@@ -67,6 +67,74 @@ static gboolean playCurrentSchedule (void * ctr) {
     return false;
 }
 
+static Node *playlistMetaSelector (GtkWidget *selector, Node *meta, int index) {
+    for (Node *c = meta->firstChild (); c; c = c->nextSibling ()) {
+        if (id_node_meta_views == c->id) {
+            for (Node *v = c->firstChild (); v; v = v->nextSibling ())
+                if (id_node_meta_views == c->id) {
+                    PlaylistRole *pr = (PlaylistRole *) v->role (RoleCaption);
+                    if (pr) {
+                        if (selector)
+                            hildon_touch_selector_append_text (
+                                    HILDON_TOUCH_SELECTOR (selector),
+                                    pr->caption ());
+                        else if (--index < 0)
+                            return v;
+                    }
+                }
+        } else if (id_node_playlist_item == c->id) {
+            PlaylistRole *pr = (PlaylistRole *) c->role (RoleCaption);
+            if (pr) {
+                if (selector)
+                    hildon_touch_selector_append_text (
+                            HILDON_TOUCH_SELECTOR (selector),
+                            pr->caption ());
+                else if (--index < 0)
+                    return c;
+            }
+        }
+    }
+    return NULL;
+}
+
+static void
+playlistMetaResponse (GtkDialog *dialog, gint response, gpointer data) {
+    Node **node = (Node **)data;
+    HildonTouchSelector *sel = hildon_picker_dialog_get_selector (
+            HILDON_PICKER_DIALOG (dialog));
+
+    if (response == GTK_RESPONSE_OK) {
+        int i = hildon_touch_selector_get_active(HILDON_TOUCH_SELECTOR(sel), 0);
+        *node = playlistMetaSelector (NULL, *node, i);
+    } else {
+        *node = NULL;
+    }
+}
+
+static void playlistMetaActivated (Node *meta, Application *app) {
+    Control *ctrl = CONTROL(app);
+    GtkWidget *dialog = hildon_picker_dialog_new (app->window);
+    GtkWidget *selector = hildon_touch_selector_new_text();
+    Node *selected_node = meta;
+
+    hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (dialog),
+            HILDON_TOUCH_SELECTOR (selector));
+    g_signal_connect (G_OBJECT (dialog), "response",
+            G_CALLBACK (playlistMetaResponse), &selected_node);
+
+    playlistMetaSelector (selector, meta, 0);
+
+    PlaylistRole *pr = (PlaylistRole *) meta->role (RolePlaylist);
+    if (pr)
+        gtk_window_set_title (GTK_WINDOW (dialog), pr->caption ());
+
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+
+    if (selected_node)
+        jump (selected_node, ctrl);
+}
+
 SourceDocument::SourceDocument (Control *c, const String &url)
     : Document (url, c), m_control (c) {}
 
@@ -95,6 +163,10 @@ void SourceDocument::message (MessageType msg, void *data) {
             }
         return;
 
+    case MsgShowMeta:
+        playlistMetaActivated ((Node *) data, m_control->m_app);
+        return;
+
     default:
         break;
     }
@@ -853,7 +925,7 @@ void Control::addRecent (const String &url, const String &title) {
         Recent *rec = new Recent (recents, m_app, url);
         recents->insertBefore (rec, c);
         if (!title.isEmpty ())
-            rec->setAttribute (StringPool::attr_title, title);
+            rec->setAttribute (Ids::attr_title, title);
         rec->closed ();
         c = recents->firstChild ()->nextSibling ();
         int count = 1;
@@ -970,7 +1042,7 @@ Application *app_new () {
     memset (app, 0, sizeof (Application));
     app->control = new Control (app);
     app->show_playlist = true;
-    StringPool::init();
+    Ids::init();
     app->viewarea = new ViewArea (app);
     app->top_most_window = true;
     return app;
@@ -979,7 +1051,7 @@ Application *app_new () {
 void app_destroy (Application *app) {
     delete CONTROL(app);
     delete VIEWAREA(app);
-    StringPool::reset ();
+    Ids::reset ();
 }
 
 void app_init_control (Application *app) {
@@ -1012,7 +1084,11 @@ static Mrl *findFirstPlayable (Node *n) {
 
 void KMPlayer::jump (Node *n, Control *ctr) {
     Mrl *mrl = n->document() != ctr->playlist_data->document
-        ? isListItem (n->id) || id_node_meta_view == n->id ? n->mrl () : NULL
+        ? isListItem (n->id) ||
+          id_node_meta_view == n->id ||
+          id_node_meta_group == n->id
+              ? n->mrl ()
+              : NULL
         : findFirstPlayable (n);
     if (mrl && mrl->view_mode == Mrl::SingleMode) {
         if (n->document() == ctr->playlist_data->document && !mrl->isPlayable())
@@ -1151,7 +1227,7 @@ void cb_favorites_add (GtkButton *, Application *app) {
                 } else {
                     PlaylistItem *i = new PlaylistItem (doc, app, false, mrl->src);
                     if (!mrl->title.isEmpty ())
-                        i->setAttribute (StringPool::attr_title, mrl->title);
+                        i->setAttribute (Ids::attr_title, mrl->title);
                     i->closed ();
                     fav->document->appendChild (i);
                 }
@@ -1476,10 +1552,10 @@ static void getGenerators (Control *ctrl, const String &dir) {
             Node *n = gen->firstChild ();
             if (n && n->isElementNode ()) {
                 String txt = static_cast <Element *> (n)->getAttribute (
-                        StringPool::attr_name);
+                        Ids::attr_name);
                 if (txt.isEmpty ())
                     txt = file;
-                gen->setAttribute (StringPool::attr_name, txt);
+                gen->setAttribute (Ids::attr_name, txt);
                 ctrl->generators.append (new NodeStoreItem (doc));
             } else {
                 gen->dispose ();
@@ -1500,7 +1576,7 @@ generatorResponse (GtkDialog *dialog, gint response, gpointer data) {
         gchar *selection = hildon_touch_selector_get_current_text (sel);
         for (NodeStoreItem *s = ctrl->generators.first(); s; s = s->nextSibling()) {
             String txt = static_cast <Element *> (s->data.ptr())->getAttribute (
-                    StringPool::attr_name);
+                    Ids::attr_name);
             if (txt == selection) {
                 ctrl->current_generator = s->data;
                 return;
@@ -1531,7 +1607,7 @@ void generatorMenuActivate (GtkMenuItem *item, Application *app) {
 
     for (NodeStoreItem *s = ctrl->generators.first(); s; s = s->nextSibling()) {
         String txt = static_cast <Element *> (s->data.ptr ())->getAttribute (
-                StringPool::attr_name);
+                Ids::attr_name);
         hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
                                 txt);
     }
