@@ -869,7 +869,7 @@ String *Mrl::parsePanZoomString (const String &pz, String *coord) {
 //----------------------%<-----------------------------------------------------
 
 void Mrl::parseParam (const TrieString & para, const String & val) {
-    if (para == StringPool::attr_src && !src.startsWith ("#")) {
+    if (para == Ids::attr_src && !src.startsWith ("#")) {
         String abs = absolutePath ();
         if (abs != src)
             src = val;
@@ -920,7 +920,7 @@ Document::Document (const String & s, PlayListNotify * n)
     m_doc = m_self; // just-in-time setting fragile m_self to m_doc
     src = s;
     if (!s.isEmpty ())
-        setAttribute (StringPool::attr_src, s);
+        setAttribute (Ids::attr_src, s);
 }
 
 Document::~Document () {
@@ -932,7 +932,7 @@ static Node *getElementByIdImpl (Node *n, const String & id, bool inter) {
     if (!n->isElementNode ())
         return NULL;
     Element *e = static_cast <Element *> (n);
-    if (e->getAttribute (StringPool::attr_id) == id)
+    if (e->getAttribute (Ids::attr_id) == id)
         return n;
     for (Node *c = e->firstChild (); c; c = c->nextSibling ()) {
         if (!inter && c->mrl () && c->mrl ()->opener.ptr () == n)
@@ -1346,15 +1346,15 @@ GenericURL::GenericURL (NodePtr & d, const String & s, const String & name)
  : Mrl (d) {
     src = s;
     if (!src.isEmpty ())
-        setAttribute (StringPool::attr_src, src);
+        setAttribute (Ids::attr_src, src);
     title = name;
     if (!name.isEmpty ())
-        setAttribute (StringPool::attr_title, name);
+        setAttribute (Ids::attr_title, name);
 }
 
 KDE_NO_EXPORT void GenericURL::closed () {
     if (src.isEmpty ())
-        src = getAttribute (StringPool::attr_src);
+        src = getAttribute (Ids::attr_src);
     Mrl::closed ();
 }
 
@@ -1364,20 +1364,20 @@ GenericMrl::GenericMrl (NodePtr & d, const String & s, const String & name, cons
  : Mrl (d), node_name (tag) {
     src = s;
     if (!src.isEmpty ())
-        setAttribute (StringPool::attr_src, src);
+        setAttribute (Ids::attr_src, src);
     title = name;
     if (!name.isEmpty ())
-        setAttribute (StringPool::attr_name, name);
+        setAttribute (Ids::attr_name, name);
 }
 
 void GenericMrl::closed () {
     if (src.isEmpty ()) {
-        src = getAttribute (StringPool::attr_src);
+        src = getAttribute (Ids::attr_src);
         if (src.isEmpty ())
-            src = getAttribute (StringPool::attr_url);
+            src = getAttribute (Ids::attr_url);
     }
     if (title.isEmpty ())
-        title = getAttribute (StringPool::attr_name);
+        title = getAttribute (Ids::attr_name);
     Mrl::closed ();
 }
 
