@@ -242,6 +242,7 @@ enum MessageType
     MsgChildReady,
     MsgChildTransformedIn,
     MsgChildFinished,
+    MsgShowMeta,
 
     MsgInfoString                // String*
 };
@@ -255,7 +256,8 @@ enum RoleType
     RoleChildDisplay,    // Mrl*
     RoleSizer,
     RoleReceivers,
-    RolePlaylist
+    RolePlaylist,
+    RoleCaption
 };
 
 #define MsgUnhandled ((void *) 357L)
