@@ -57,7 +57,6 @@ public:
     void keyPressEvent (int keyval, const char *str);
     void paintEvent (const IRect &);
     bool timeoutPaintEvent ();
-    void controlsVisible (Application *app, bool show);
     void prepareFullscreenToggle ();
     void enableVideoInputFilter (bool enable);
     KDE_NO_EXPORT IRect videoGeometry () const { return m_av_geometry; }
@@ -68,9 +67,6 @@ public:
     unsigned long videoXId () const;
     Mrl *videoMrl () { return video_node ? video_node->mrl () : NULL; }
     void setOutputWidget (Application *, GtkWidget * w);
-    void setControlsOverlap (bool b) { m_controls_overlap = b; }
-    GdkWindow *controls;
-    int controls_timer;
 private:
     void syncVisual (const IRect & rect);
     void updateSurfaceBounds ();
@@ -94,7 +90,6 @@ private:
     bool m_fullscreen;
     bool m_event_filter_on;
     bool m_updaters_enabled;
-    bool m_controls_overlap;
     bool m_video_filter;
 };
 
